==> jc-1.4.0.tar.gz: gnu/java/rmi/server/UnicastServer.h <==
// public class gnu.java.rmi.server.UnicastServer

// class file dependencies
// @dep_class 63896540648b6717 gnu_java_rmi_server_UnicastServer
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_rmi_server_UnicastServer_H_
#define _JC_gnu_java_rmi_server_UnicastServer_H_

// Forward structure declarations
struct _jc_gnu_java_rmi_dgc_DGCImpl$object;
struct _jc_gnu_java_rmi_server_UnicastConnection$object;
struct _jc_gnu_java_rmi_server_UnicastServerRef$object;
struct _jc_java_lang_Class$object;
struct _jc_java_rmi_Remote$object;
struct _jc_java_util_Hashtable$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_server_UnicastServer$sub_refs	_jc_gnu_java_rmi_server_UnicastServer$sub_refs;
typedef struct _jc_gnu_java_rmi_server_UnicastServer$sub_nonrefs	_jc_gnu_java_rmi_server_UnicastServer$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_server_UnicastServer$refs	_jc_gnu_java_rmi_server_UnicastServer$refs;
typedef struct _jc_gnu_java_rmi_server_UnicastServer$nonrefs	_jc_gnu_java_rmi_server_UnicastServer$nonrefs;
typedef struct _jc_gnu_java_rmi_server_UnicastServer$object	_jc_gnu_java_rmi_server_UnicastServer$object;

typedef struct _jc_gnu_java_rmi_server_UnicastServer$fields_struct	_jc_gnu_java_rmi_server_UnicastServer$fields_struct;
typedef const struct _jc_gnu_java_rmi_server_UnicastServer$vmethods	_jc_gnu_java_rmi_server_UnicastServer$vmethods;
typedef const struct _jc_gnu_java_rmi_server_UnicastServer$vtable	_jc_gnu_java_rmi_server_UnicastServer$vtable;
typedef const struct _jc_gnu_java_rmi_server_UnicastServer$vtype	_jc_gnu_java_rmi_server_UnicastServer$vtype;

// Class fields structure
struct _jc_gnu_java_rmi_server_UnicastServer$fields_struct {
	struct _jc_gnu_java_rmi_dgc_DGCImpl$object	*dgc;
	struct _jc_java_util_Hashtable$object	*objects;
	struct _jc_java_util_Hashtable$object	*refcache;
};
extern _jc_gnu_java_rmi_server_UnicastServer$fields_struct _jc_gnu_java_rmi_server_UnicastServer$class_fields;

// Constructors
extern void _jc_gnu_java_rmi_server_UnicastServer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_rmi_server_UnicastServer$object *);

// Static methods
extern void _jc_gnu_java_rmi_server_UnicastServer$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern void _jc_gnu_java_rmi_server_UnicastServer$method$dispatch$0462a98e299c9279(_jc_env *, struct _jc_gnu_java_rmi_server_UnicastConnection$object *);
extern void _jc_gnu_java_rmi_server_UnicastServer$method$exportObject$592a7dc5bf63c379(_jc_env *, struct _jc_gnu_java_rmi_server_UnicastServerRef$object *);
extern struct _jc_gnu_java_rmi_server_UnicastServerRef$object *_jc_gnu_java_rmi_server_UnicastServer$method$getExportedRef$9dcdaeacaa406590(_jc_env *, struct _jc_object *);
extern void _jc_gnu_java_rmi_server_UnicastServer$method$incomingMessageCall$c75d22d795dc5c7e(_jc_env *, struct _jc_gnu_java_rmi_server_UnicastConnection$object *);
extern void _jc_gnu_java_rmi_server_UnicastServer$method$startDGC$23ff54c3f773aa45(_jc_env *);
extern jboolean _jc_gnu_java_rmi_server_UnicastServer$method$unexportObject$0f75126117f7d456(_jc_env *, struct _jc_gnu_java_rmi_server_UnicastServerRef$object *, jboolean);

// Virtual methods structure
struct _jc_gnu_java_rmi_server_UnicastServer$vmethods {
};

// Vtable
struct _jc_gnu_java_rmi_server_UnicastServer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_rmi_server_UnicastServer$vmethods	gnu_java_rmi_server_UnicastServer;
};

// Vtype
struct _jc_gnu_java_rmi_server_UnicastServer$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_server_UnicastServer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_UnicastServer$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_server_UnicastServer$refs {
    _jc_gnu_java_rmi_server_UnicastServer$sub_refs	gnu_java_rmi_server_UnicastServer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_UnicastServer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_server_UnicastServer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_rmi_server_UnicastServer$sub_nonrefs	gnu_java_rmi_server_UnicastServer;
};

// Object instance structure
struct _jc_gnu_java_rmi_server_UnicastServer$object {
	_jc_gnu_java_rmi_server_UnicastServer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_server_UnicastServer$vtype	*vtype;
	_jc_gnu_java_rmi_server_UnicastServer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_server_UnicastServer$vtype _jc_gnu_java_rmi_server_UnicastServer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_server_UnicastServer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_server_UnicastServer$class_object;

#endif	/* _JC_gnu_java_rmi_server_UnicastServer_H_ */

==> jc-1.4.6.tar.gz: gnu/java/rmi/server/UnicastServer.h <==
// public class gnu.java.rmi.server.UnicastServer

// class file dependencies
// @dep_class 63896540648b6717 gnu_java_rmi_server_UnicastServer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_rmi_server_UnicastServer_H_
#define _JC_gnu_java_rmi_server_UnicastServer_H_

// Forward structure declarations
struct _jc_gnu_java_rmi_dgc_DGCImpl$object;
struct _jc_gnu_java_rmi_server_UnicastConnection$object;
struct _jc_gnu_java_rmi_server_UnicastServerRef$object;
struct _jc_java_lang_Class$object;
struct _jc_java_rmi_Remote$object;
struct _jc_java_util_Hashtable$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_server_UnicastServer$sub_refs	_jc_gnu_java_rmi_server_UnicastServer$sub_refs;
typedef struct _jc_gnu_java_rmi_server_UnicastServer$sub_nonrefs	_jc_gnu_java_rmi_server_UnicastServer$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_server_UnicastServer$refs	_jc_gnu_java_rmi_server_UnicastServer$refs;
typedef struct _jc_gnu_java_rmi_server_UnicastServer$nonrefs	_jc_gnu_java_rmi_server_UnicastServer$nonrefs;
typedef struct _jc_gnu_java_rmi_server_UnicastServer$object	_jc_gnu_java_rmi_server_UnicastServer$object;

typedef struct _jc_gnu_java_rmi_server_UnicastServer$fields_struct	_jc_gnu_java_rmi_server_UnicastServer$fields_struct;
typedef const struct _jc_gnu_java_rmi_server_UnicastServer$vmethods	_jc_gnu_java_rmi_server_UnicastServer$vmethods;
typedef const struct _jc_gnu_java_rmi_server_UnicastServer$vtable	_jc_gnu_java_rmi_server_UnicastServer$vtable;
typedef const struct _jc_gnu_java_rmi_server_UnicastServer$vtype	_jc_gnu_java_rmi_server_UnicastServer$vtype;

// Class fields structure
struct _jc_gnu_java_rmi_server_UnicastServer$fields_struct {
	struct _jc_gnu_java_rmi_dgc_DGCImpl$object	*dgc;
	struct _jc_java_util_Hashtable$object	*objects;
	struct _jc_java_util_Hashtable$object	*refcache;
};
extern _jc_gnu_java_rmi_server_UnicastServer$fields_struct _jc_gnu_java_rmi_server_UnicastServer$class_fields;

// Constructors
extern void _jc_gnu_java_rmi_server_UnicastServer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_rmi_server_UnicastServer$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_gnu_java_rmi_server_UnicastServer$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_rmi_server_UnicastServer$method$dispatch$0462a98e299c9279(_jc_env *, struct _jc_gnu_java_rmi_server_UnicastConnection$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_rmi_server_UnicastServer$method$exportObject$592a7dc5bf63c379(_jc_env *, struct _jc_gnu_java_rmi_server_UnicastServerRef$object *) _JC_JCNI_ATTR;
extern struct _jc_gnu_java_rmi_server_UnicastServerRef$object *_jc_gnu_java_rmi_server_UnicastServer$method$getExportedRef$9dcdaeacaa406590(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_rmi_server_UnicastServer$method$incomingMessageCall$c75d22d795dc5c7e(_jc_env *, struct _jc_gnu_java_rmi_server_UnicastConnection$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_rmi_server_UnicastServer$method$startDGC$23ff54c3f773aa45(_jc_env *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_java_rmi_server_UnicastServer$method$unexportObject$0f75126117f7d456(_jc_env *, struct _jc_gnu_java_rmi_server_UnicastServerRef$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_rmi_server_UnicastServer$vmethods {
};

// Vtable
struct _jc_gnu_java_rmi_server_UnicastServer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_rmi_server_UnicastServer$vmethods	gnu_java_rmi_server_UnicastServer;
};

// Vtype
struct _jc_gnu_java_rmi_server_UnicastServer$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_server_UnicastServer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_UnicastServer$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_server_UnicastServer$refs {
    _jc_gnu_java_rmi_server_UnicastServer$sub_refs	gnu_java_rmi_server_UnicastServer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_UnicastServer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_server_UnicastServer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_rmi_server_UnicastServer$sub_nonrefs	gnu_java_rmi_server_UnicastServer;
};

// Object instance structure
struct _jc_gnu_java_rmi_server_UnicastServer$object {
	_jc_gnu_java_rmi_server_UnicastServer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_server_UnicastServer$vtype	*vtype;
	_jc_gnu_java_rmi_server_UnicastServer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_server_UnicastServer$vtype _jc_gnu_java_rmi_server_UnicastServer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_server_UnicastServer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_server_UnicastServer$class_object;

#endif	/* _JC_gnu_java_rmi_server_UnicastServer_H_ */
